@@ -6,18 +6,18 @@
 */
 
 #include "collectiongeneralpage.h"
-#include <PimCommon/PimUtil>
+#include <Akonadi/Calendar/BlockAlarmsAttribute>
 #include <Collection>
 #include <EntityDisplayAttribute>
-#include <Akonadi/Calendar/BlockAlarmsAttribute>
+#include <PimCommon/PimUtil>
 
 #include <KCalendarCore/Event>
 #include <KCalendarCore/Journal>
 #include <KCalendarCore/Todo>
 
 #include <KIconButton>
-#include <QLineEdit>
 #include <KLocalizedString>
+#include <QLineEdit>
 
 #include <QCheckBox>
 #include <QHBoxLayout>
@@ -40,20 +40,17 @@ CollectionGeneralPage::CollectionGeneralPage(QWidget *parent)
 
 void CollectionGeneralPage::init(const Akonadi::Collection &collection)
 {
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
 
-    auto *hbox = new QHBoxLayout();
+    auto hbox = new QHBoxLayout();
     topLayout->addItem(hbox);
 
-    QLabel *label = new QLabel(i18nc("@label:textbox Name of the folder.", "&Name:"), this);
+    auto label = new QLabel(i18nc("@label:textbox Name of the folder.", "&Name:"), this);
     hbox->addWidget(label);
 
     mNameEdit = new QLineEdit(this);
-    mNameEdit->setToolTip(
-        i18nc("@info:tooltip", "Set the folder name"));
-    mNameEdit->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "Enter a name here to set the name of this folder."));
+    mNameEdit->setToolTip(i18nc("@info:tooltip", "Set the folder name"));
+    mNameEdit->setWhatsThis(i18nc("@info:whatsthis", "Enter a name here to set the name of this folder."));
     label->setBuddy(mNameEdit);
     hbox->addWidget(mNameEdit);
 
@@ -62,44 +59,31 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
     topLayout->addItem(hbox);
 
     mBlockAlarmsCheckBox = new QCheckBox(i18nc("@option:check", "Block reminders locally"), this);
-    mBlockAlarmsCheckBox->setToolTip(
-        i18nc("@info:tooltip", "Ignore reminders from this calendar"));
-    mBlockAlarmsCheckBox->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "Check this box if you do not want to receive reminders from items "
-              "associated with this calendar."));
+    mBlockAlarmsCheckBox->setToolTip(i18nc("@info:tooltip", "Ignore reminders from this calendar"));
+    mBlockAlarmsCheckBox->setWhatsThis(i18nc("@info:whatsthis",
+                                             "Check this box if you do not want to receive reminders from items "
+                                             "associated with this calendar."));
     hbox->addWidget(mBlockAlarmsCheckBox);
 
     hbox = new QHBoxLayout();
     topLayout->addItem(hbox);
     mIconCheckBox = new QCheckBox(i18nc("@option:check", "&Use custom icon:"), this);
-    mIconCheckBox->setToolTip(
-        i18nc("@info:tooltip", "Set a custom icon"));
-    mIconCheckBox->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "Check this box if you want to set a custom icon for this folder."));
+    mIconCheckBox->setToolTip(i18nc("@info:tooltip", "Set a custom icon"));
+    mIconCheckBox->setWhatsThis(i18nc("@info:whatsthis", "Check this box if you want to set a custom icon for this folder."));
     mIconButton = new KIconButton(this);
     mIconButton->setIconSize(16);
     hbox->addWidget(mIconCheckBox);
     hbox->addWidget(mIconButton);
     hbox->addStretch();
 
-    if ((collection.parentCollection() != Akonadi::Collection::root())
-        && PimCommon::Util::isImapResource(collection.resource())) {
-        const auto *annotationAttribute
-            = collection.attribute<PimCommon::CollectionAnnotationsAttribute>();
+    if ((collection.parentCollection() != Akonadi::Collection::root()) && PimCommon::Util::isImapResource(collection.resource())) {
+        const auto *annotationAttribute = collection.attribute<PimCommon::CollectionAnnotationsAttribute>();
 
-        const QMap<QByteArray, QByteArray> annotations
-            = (annotationAttribute
-               ? annotationAttribute->annotations()
-               : QMap<QByteArray, QByteArray>());
+        const QMap<QByteArray, QByteArray> annotations = (annotationAttribute ? annotationAttribute->annotations() : QMap<QByteArray, QByteArray>());
 
         PimCommon::CollectionTypeUtil collectionUtil;
-        const PimCommon::CollectionTypeUtil::IncidencesFor incidencesFor
-            = collectionUtil.incidencesForFromString(QLatin1String(annotations.value(PimCommon::
-                                                                                     CollectionTypeUtil
-                                                                                     ::
-                                                                                     kolabIncidencesFor())));
+        const PimCommon::CollectionTypeUtil::IncidencesFor incidencesFor =
+            collectionUtil.incidencesForFromString(QLatin1String(annotations.value(PimCommon::CollectionTypeUtil ::kolabIncidencesFor())));
         hbox = new QHBoxLayout();
         topLayout->addItem(hbox);
         mIncidencesForComboBox = new PimCommon::IncidencesForWidget(this);
@@ -107,7 +91,7 @@ void CollectionGeneralPage::init(const Akonadi::Collection &collection)
 
         mIncidencesForComboBox->setCurrentIndex(incidencesFor);
     }
-    topLayout->addStretch(100);   // eat all superfluous space
+    topLayout->addStretch(100); // eat all superfluous space
 }
 
 CollectionGeneralPage::~CollectionGeneralPage()
@@ -122,9 +106,7 @@ void CollectionGeneralPage::load(const Akonadi::Collection &collection)
     const QString displayName = collection.displayName();
 
     mNameEdit->setText(displayName);
-    mBlockAlarmsCheckBox->setChecked(
-        collection.hasAttribute<BlockAlarmsAttribute>()
-        && collection.attribute<BlockAlarmsAttribute>()->isEverythingBlocked());
+    mBlockAlarmsCheckBox->setChecked(collection.hasAttribute<BlockAlarmsAttribute>() && collection.attribute<BlockAlarmsAttribute>()->isEverythingBlocked());
 
     QString iconName;
     if (collection.hasAttribute<EntityDisplayAttribute>()) {
@@ -133,8 +115,7 @@ void CollectionGeneralPage::load(const Akonadi::Collection &collection)
 
     if (iconName.isEmpty()) {
         const QStringList mimeTypes = collection.contentMimeTypes();
-        if (collection.contentMimeTypes().count() > 1
-            || collection.contentMimeTypes().contains(KCalendarCore::Event::eventMimeType())) {
+        if (collection.contentMimeTypes().count() > 1 || collection.contentMimeTypes().contains(KCalendarCore::Event::eventMimeType())) {
             mIconButton->setIcon(QIcon::fromTheme(QStringLiteral("view-pim-calendar")));
         } else if (collection.contentMimeTypes().contains(KCalendarCore::Todo::todoMimeType())) {
             mIconButton->setIcon(QIcon::fromTheme(QStringLiteral("view-pim-tasks")));
@@ -153,34 +134,28 @@ void CollectionGeneralPage::load(const Akonadi::Collection &collection)
 
 void CollectionGeneralPage::save(Collection &collection)
 {
-    if (collection.hasAttribute<EntityDisplayAttribute>()
-        && !collection.attribute<EntityDisplayAttribute>()->displayName().isEmpty()) {
+    if (collection.hasAttribute<EntityDisplayAttribute>() && !collection.attribute<EntityDisplayAttribute>()->displayName().isEmpty()) {
         collection.attribute<EntityDisplayAttribute>()->setDisplayName(mNameEdit->text());
     } else {
         collection.setName(mNameEdit->text());
     }
 
-    auto *attr
-        = collection.attribute<BlockAlarmsAttribute>(Collection::AddIfMissing);
+    auto *attr = collection.attribute<BlockAlarmsAttribute>(Collection::AddIfMissing);
     attr->blockEverything(mBlockAlarmsCheckBox->isChecked());
 
     if (mIconCheckBox->isChecked()) {
-        collection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing)->
-        setIconName(mIconButton->icon());
+        collection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing)->setIconName(mIconButton->icon());
     } else if (collection.hasAttribute<EntityDisplayAttribute>()) {
         collection.attribute<EntityDisplayAttribute>()->setIconName(QString());
     }
-    auto *annotationsAttribute
-        = collection.attribute<PimCommon::CollectionAnnotationsAttribute>(Collection::AddIfMissing);
+    auto *annotationsAttribute = collection.attribute<PimCommon::CollectionAnnotationsAttribute>(Collection::AddIfMissing);
 
     QMap<QByteArray, QByteArray> annotations = annotationsAttribute->annotations();
 
     PimCommon::CollectionTypeUtil collectionUtil;
     if (mIncidencesForComboBox && mIncidencesForComboBox->isEnabled()) {
-        annotations[ PimCommon::CollectionTypeUtil::kolabIncidencesFor() ]
-            = collectionUtil.incidencesForToString(
-                  static_cast<PimCommon::CollectionTypeUtil::IncidencesFor>(mIncidencesForComboBox->
-                                                                            currentIndex())).toLatin1();
+        annotations[PimCommon::CollectionTypeUtil::kolabIncidencesFor()] =
+            collectionUtil.incidencesForToString(static_cast<PimCommon::CollectionTypeUtil::IncidencesFor>(mIncidencesForComboBox->currentIndex())).toLatin1();
     }
 
     if (annotations.isEmpty()) {
