@@ -20,7 +20,7 @@ class DateChecker : public QObject
     Q_OBJECT
 public:
     explicit DateChecker(QObject *parent = nullptr);
-    ~DateChecker();
+    ~DateChecker() override;
 
     /**
       The DateChecker automatically checks for
@@ -33,11 +33,7 @@ public:
       as FollowDay but also adjusts the month that is
       visible and emits monthPassed() when the month changes.
     */
-    enum RolloverType {
-        None,
-        FollowDay,
-        FollowMonth
-    };
+    enum RolloverType { None, FollowDay, FollowMonth };
     void enableRollover(RolloverType);
 
 Q_SIGNALS:
