@@ -231,7 +231,7 @@ void ApptSummaryWidget::viewEvent(const QString &uid)
 
 void ApptSummaryWidget::removeEvent(const Akonadi::Item &item)
 {
-    mChanger->deleteIncidence(item);
+    (void) mChanger->deleteIncidence(item);
 }
 
 void ApptSummaryWidget::popupMenu(const QString &uid)
