@@ -12,7 +12,8 @@
 
 class OrgKdeKorganizerCalendarInterface;
 
-namespace KontactInterface {
+namespace KontactInterface
+{
 class UniqueAppWatcher;
 }
 
