@@ -99,7 +99,7 @@ QStringList TodoPlugin::invisibleToolbarActions() const
 OrgKdeKorganizerCalendarInterface *TodoPlugin::interface()
 {
     if (!mIface) {
-        part();
+        (void) part();
     }
     Q_ASSERT(mIface);
     return mIface;
