@@ -11,21 +11,20 @@
 #include "aboutdata.h"
 #include "actionmanager.h"
 #include "calendarview.h"
-#include "kocore.h"
 #include "impl/korganizerifaceimpl.h"
+#include "kocore.h"
 #include <CalendarSupport/Utils>
 
 #include <KCalUtils/IncidenceFormatter>
 
-#include <QStatusBar>
-#include <KParts/StatusBarExtension>
 #include "korganizer_debug.h"
 #include "korgmigrateapplication.h"
+#include <KParts/StatusBarExtension>
+#include <QStatusBar>
 
 #include <QVBoxLayout>
 
-K_PLUGIN_FACTORY(KOrganizerFactory, registerPlugin<KOrganizerPart>();
-                 )
+K_PLUGIN_FACTORY(KOrganizerFactory, registerPlugin<KOrganizerPart>();)
 
 KOrganizerPart::KOrganizerPart(QWidget *parentWidget, QObject *parent, const QVariantList &)
     : KParts::ReadOnlyPart(parent)
@@ -35,7 +34,7 @@ KOrganizerPart::KOrganizerPart(QWidget *parentWidget, QObject *parent, const QVa
     if (parentWidget) {
         mTopLevelWidget = parentWidget->topLevelWidget();
     } else if (parent && parent->isWidgetType()) {
-        mTopLevelWidget = dynamic_cast<QWidget *>(parent);
+        mTopLevelWidget = qobject_cast<QWidget *>(parent);
     } else {
         qCCritical(KORGANIZER_LOG) << "Cannot initialize the part without a top level widget.";
     }
@@ -58,7 +57,7 @@ KOrganizerPart::KOrganizerPart(QWidget *parentWidget, QObject *parent, const QVa
     mStatusBarExtension = new KParts::StatusBarExtension(this);
     setComponentName(QStringLiteral("korganizer"), i18n("KOrganizer"));
 
-    auto *topLayout = new QVBoxLayout(canvas);
+    auto topLayout = new QVBoxLayout(canvas);
     topLayout->addWidget(mView);
     topLayout->setContentsMargins({});
 
@@ -84,12 +83,11 @@ KOrganizerPart::~KOrganizerPart()
 
 void KOrganizerPart::slotChangeInfo(const Akonadi::Item &item, const QDate &date)
 {
-    Q_UNUSED(date);
+    Q_UNUSED(date)
     const KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
     if (incidence) {
         Q_EMIT textChanged(incidence->summary() + QLatin1String(" / ")
-                           +KCalUtils::IncidenceFormatter::timeToString(incidence->dtStart().
-                                                                        toLocalTime().time()));
+                           + KCalUtils::IncidenceFormatter::timeToString(incidence->dtStart().toLocalTime().time()));
     } else {
         Q_EMIT textChanged(QString());
     }
@@ -147,10 +145,10 @@ bool KOrganizerPart::openFile()
 // FIXME: This is copied verbatim from the KOrganizer class. Move it to the common base class!
 void KOrganizerPart::setTitle()
 {
-//  qCDebug(KORGANIZER_LOG) <<"KOrganizer::setTitle";
-// FIXME: Inside kontact we want to have different titles depending on the
-//        type of view (calendar, to-do, journal). How can I add the filter
-//        name in that case?
+    //  qCDebug(KORGANIZER_LOG) <<"KOrganizer::setTitle";
+    // FIXME: Inside kontact we want to have different titles depending on the
+    //        type of view (calendar, to-do, journal). How can I add the filter
+    //        name in that case?
     /*
       QString title;
       if ( !hasDocument() ) {
