@@ -11,7 +11,8 @@
 
 #include <QObject>
 
-namespace KOrg {
+namespace KOrg
+{
 class MainWindow;
 }
 
