@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef MANAGESHOWCOLLECTIONPROPERTIES_H
 #define MANAGESHOWCOLLECTIONPROPERTIES_H
 
+#include <AkonadiCore/Collection>
 #include <QObject>
 #include <QPointer>
-#include <AkonadiCore/Collection>
-namespace Akonadi {
+namespace Akonadi
+{
 class CollectionPropertiesDialog;
 }
 class KJob;
@@ -20,7 +21,7 @@ class ManageShowCollectionProperties : public QObject
     Q_OBJECT
 public:
     explicit ManageShowCollectionProperties(AkonadiCollectionView *collectionView, QObject *parent = nullptr);
-    ~ManageShowCollectionProperties();
+    ~ManageShowCollectionProperties() override;
 
 public Q_SLOTS:
     void showCollectionProperties();
@@ -28,7 +29,7 @@ public Q_SLOTS:
 private:
     void slotCollectionPropertiesContinued(KJob *job);
     void slotCollectionPropertiesFinished(KJob *job);
-    QHash<Akonadi::Collection::Id, QPointer<Akonadi::CollectionPropertiesDialog> > mHashDialogBox;
+    QHash<Akonadi::Collection::Id, QPointer<Akonadi::CollectionPropertiesDialog>> mHashDialogBox;
     const QStringList mPages;
     AkonadiCollectionView *const mCollectionView;
 };
