@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,14 +7,14 @@
 #ifndef KORGANIZERPLUGININTERFACE_H
 #define KORGANIZERPLUGININTERFACE_H
 
-#include <QObject>
 #include <PimCommonAkonadi/PluginInterface>
+#include <QObject>
 class KOrganizerPluginInterface : public PimCommon::PluginInterface
 {
     Q_OBJECT
 public:
     explicit KOrganizerPluginInterface(QObject *parent = nullptr);
-    ~KOrganizerPluginInterface();
+    ~KOrganizerPluginInterface() override;
     static KOrganizerPluginInterface *self();
 };
 
