@@ -15,7 +15,8 @@
 
 class QComboBox;
 class KColorButton;
-namespace Akonadi {
+namespace Akonadi
+{
 class CollectionComboBox;
 }
 
@@ -23,7 +24,7 @@ class KOPrefsDialogColorsAndFonts : public Korganizer::KPrefsModule
 {
     Q_OBJECT
 public:
-    KOPrefsDialogColorsAndFonts(QWidget *parent);
+    explicit KOPrefsDialogColorsAndFonts(QWidget *parent);
 
 protected:
     void usrWriteConfig() override;
