@@ -10,8 +10,8 @@
 
 #include <KCalendarCore/IncidenceBase> // for KCalendarCore::DateList typedef
 
-#include <QWidget>
 #include <QDate>
+#include <QWidget>
 class QToolButton;
 
 class NavigatorBar : public QWidget
@@ -19,7 +19,7 @@ class NavigatorBar : public QWidget
     Q_OBJECT
 public:
     explicit NavigatorBar(QWidget *parent = nullptr);
-    ~NavigatorBar();
+    ~NavigatorBar() override;
 
     void showButtons(bool left, bool right);
 
